# Update the puppet agent version on Windows and Linux

class puppet_agent ($version = undef, $ssldir = undef, $server = undef, $environment = undef, $pkg_name = undef) {
  $module_path = 'puppet:///modules/puppet_agent'

  case $operatingsystem {
    centos, redhat : {
      $conf_file = '/etc/puppet/puppet.conf'
      $conf_source = 'puppet_agent/puppet_linux.conf.erb'
      $pkg_source = undef
      $pkg_require = undef
      $pkg_version = "${version}-1.el${lsbmajdistrelease}"
    }
    debian, ubuntu : {
      $conf_file = '/etc/puppet/puppet.conf'
      $conf_source = 'puppet_agent/puppet_linux.conf.erb'
      $pkg_source = undef
      $pkg_require = undef
      $pkg_version = "${version}-1puppetlabs1"
    }
    windows        : {
      include puppetstore::puppet

      $puppet_pkg = "${puppetstore::puppet::puppet_store}/puppet-${version}.msi"
      $puppet_rpkg = "${puppetstore::puppet::puppet_remote}/puppet-${version}.msi"
      $puppet_pkg_win = regsubst("${puppet_pkg}", '/', '\\', 'G')

      $conf_file = 'C:/ProgramData/PuppetLabs/puppet/etc/puppet.conf'
      $conf_source = 'puppet_agent/puppet_windows.conf.erb'
      $pkg_source = "${puppet_pkg_win}"
      $pkg_require = File[$puppet_pkg]
      $pkg_version = $version

      file { $puppet_pkg:
        source             => $puppet_rpkg,
        ensure             => present,
        source_permissions => ignore,
        require            => File[$puppetstore::puppet::puppet_store],
      }
    }
  }

  service { 'PuppetAgent':
    name      => 'puppet',
    ensure    => 'running',
    enable    => true,
    subscribe => File['puppet.conf'],
    require   => Package[$pkg_name],
  }

  file { 'puppet.conf':
    path    => $conf_file,
    ensure  => file,
    content => template($conf_source),
    require => Package[$pkg_name],
  }

  package { "${pkg_name}":
    ensure          => "${pkg_version}",
    source          => $pkg_source,
    require         => $pkg_require,
    install_options => [{
        'PUPPET_MASTER_SERVER' => $server
      }
      ],
  }
}
